@@ -16,3 +16,10 @@ test_that("treemap_fixed() correctly handles tiles with areas of 0", {
   expect_error(treemap_fixed(G20_allzero, area = "gdp_mil_usd"), "area > 0")
 })
 
+
+test_that("layout functions return areas", {
+
+  expect_identical({"gdp_mil_usd" %in% names(treemap_fixed(G20, area = "gdp_mil_usd"))}, TRUE)
+  expect_identical({"gdp_mil_usd" %in% names(treemap_squarified(G20, area = "gdp_mil_usd"))}, TRUE)
+
+})
